@@ -9,6 +9,7 @@ def configure_verbosity(debug: bool) -> None:
     if debug:
         logging.basicConfig(
             level=logging.DEBUG,
-            format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+            format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
+        )
     else:
         logging.basicConfig(level=logging.INFO, format='%(message)s')
