@@ -138,7 +138,7 @@ def echo_via_pager(
     """Echo using git's default pager.
 
     Wrap ``click.echo_via_pager``, setting some environment variables in the
-    processs to mimic the pager settings used by Git:
+    process to mimic the pager settings used by Git:
 
         The order of preference is the ``$GIT_PAGER`` environment variable,
         then ``core.pager`` configuration, then ``$PAGER``, and then the
@@ -151,7 +151,7 @@ def echo_via_pager(
         _echo_via_pager(pager, out)
         return
 
-    pager = git_config('core.parser')
+    pager = git_config('core.pager')
     if pager:
         _echo_via_pager(pager, out)
         return
@@ -207,6 +207,28 @@ def pagination_options(
     return _pagination_options
 
 
+def date_options() -> ty.Callable:
+    """Shared date bounding options."""
+
+    def _date_options(f):
+        f = click.option(
+            '--since',
+            metavar='SINCE',
+            type=click.DateTime(),
+            help='Show only items since a given date in ISO 8601 format',
+        )(f)
+        f = click.option(
+            '--before',
+            metavar='BEFORE',
+            type=click.DateTime(),
+            help='Show only items before a given date in ISO 8601 format',
+        )(f)
+
+        return f
+
+    return _date_options
+
+
 def format_options(
     original_function: ty.Optional[ty.Callable] = None,
     headers: ty.Optional[ty.Tuple[str, ...]] = None,
